@@ -428,7 +428,6 @@ add_tags_from_entry (RBEncoderGst *encoder,
 				  NULL);
 		g_date_free (date);
 	}
-#ifdef GST_TAG_MUSICBRAINZ_TRACKID
 	if (rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_MUSICBRAINZ_TRACKID)) {
 		gst_tag_list_add (tags, GST_TAG_MERGE_APPEND,
 				  GST_TAG_MUSICBRAINZ_TRACKID, rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_MUSICBRAINZ_TRACKID),
@@ -451,7 +450,7 @@ add_tags_from_entry (RBEncoderGst *encoder,
 	}
 	if (rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ARTIST_SORTNAME)) {
 		gst_tag_list_add (tags, GST_TAG_MERGE_APPEND,
-				  GST_TAG_MUSICBRAINZ_SORTNAME, rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ARTIST_SORTNAME),
+				  GST_TAG_ARTIST_SORTNAME, rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ARTIST_SORTNAME),
 				  NULL);
 	}
 	if (rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ALBUM_SORTNAME)) {
@@ -459,7 +458,6 @@ add_tags_from_entry (RBEncoderGst *encoder,
 				  GST_TAG_ALBUM_SORTNAME, rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ALBUM_SORTNAME),
 				  NULL);
 	}
-#endif
 
 	{
 		GstIterator *iter;
@@ -521,7 +519,7 @@ new_decoded_pad_cb (GstElement *decodebin, GstPad *new_pad, gboolean arg1, RBEnc
 	/* only process audio data */
 	if (strncmp (caps_string, "audio/", 6) == 0) {
 		encoder->priv->decoded_pads++;
-		enc_sinkpad = gst_element_get_pad (encoder->priv->enc,
+		enc_sinkpad = gst_element_get_static_pad (encoder->priv->enc,
 				"sink");
 		if (gst_pad_link (new_pad, enc_sinkpad) != GST_PAD_LINK_OK)
 			rb_debug ("error linking pads");
@@ -679,7 +677,7 @@ encoder_match_mime (RBEncoderGst *rbencoder, GstElement *encoder, const gchar *m
 	gboolean match = FALSE;
 	char *tmp;
 
-	srcpad = gst_element_get_pad (encoder, "src");
+	srcpad = gst_element_get_static_pad (encoder, "src");
 	element_caps = gst_pad_get_caps (srcpad);
 
 	if (element_caps == NULL) {
