@@ -51,7 +51,54 @@ G_BEGIN_DECLS
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:BOOLEAN,BOOLEAN,BOOLEAN (./rb-marshal.list:1) */
+/* BOOLEAN:BOOLEAN,BOOLEAN (./rb-marshal.list:1) */
+extern void rb_marshal_BOOLEAN__BOOLEAN_BOOLEAN (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data);
+void
+rb_marshal_BOOLEAN__BOOLEAN_BOOLEAN (GClosure     *closure,
+                                     GValue       *return_value G_GNUC_UNUSED,
+                                     guint         n_param_values,
+                                     const GValue *param_values,
+                                     gpointer      invocation_hint G_GNUC_UNUSED,
+                                     gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__BOOLEAN_BOOLEAN) (gpointer     data1,
+                                                             gboolean     arg_1,
+                                                             gboolean     arg_2,
+                                                             gpointer     data2);
+  register GMarshalFunc_BOOLEAN__BOOLEAN_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__BOOLEAN_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_boolean (param_values + 1),
+                       g_marshal_value_peek_boolean (param_values + 2),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:BOOLEAN,BOOLEAN,BOOLEAN (./rb-marshal.list:2) */
 extern void rb_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -100,7 +147,7 @@ rb_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:BOXED (./rb-marshal.list:2) */
+/* BOOLEAN:BOXED (./rb-marshal.list:3) */
 extern void rb_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -145,7 +192,7 @@ rb_marshal_BOOLEAN__BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:POINTER (./rb-marshal.list:3) */
+/* BOOLEAN:POINTER (./rb-marshal.list:4) */
 extern void rb_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -190,7 +237,7 @@ rb_marshal_BOOLEAN__POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:POINTER,POINTER,POINTER (./rb-marshal.list:4) */
+/* BOOLEAN:POINTER,POINTER,POINTER (./rb-marshal.list:5) */
 extern void rb_marshal_BOOLEAN__POINTER_POINTER_POINTER (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -239,7 +286,7 @@ rb_marshal_BOOLEAN__POINTER_POINTER_POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,BOOLEAN (./rb-marshal.list:5) */
+/* BOOLEAN:STRING,BOOLEAN (./rb-marshal.list:6) */
 extern void rb_marshal_BOOLEAN__STRING_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -286,7 +333,7 @@ rb_marshal_BOOLEAN__STRING_BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,STRING,OBJECT (./rb-marshal.list:6) */
+/* BOOLEAN:STRING,STRING,OBJECT (./rb-marshal.list:7) */
 extern void rb_marshal_BOOLEAN__STRING_STRING_OBJECT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -335,7 +382,7 @@ rb_marshal_BOOLEAN__STRING_STRING_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* INT:VOID (./rb-marshal.list:7) */
+/* INT:VOID (./rb-marshal.list:8) */
 extern void rb_marshal_INT__VOID (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
@@ -378,7 +425,7 @@ rb_marshal_INT__VOID (GClosure     *closure,
   g_value_set_int (return_value, v_return);
 }
 
-/* OBJECT:OBJECT (./rb-marshal.list:8) */
+/* OBJECT:OBJECT (./rb-marshal.list:9) */
 extern void rb_marshal_OBJECT__OBJECT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -423,7 +470,7 @@ rb_marshal_OBJECT__OBJECT (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* OBJECT:VOID (./rb-marshal.list:9) */
+/* OBJECT:VOID (./rb-marshal.list:10) */
 extern void rb_marshal_OBJECT__VOID (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -466,7 +513,7 @@ rb_marshal_OBJECT__VOID (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* STRING:STRING (./rb-marshal.list:10) */
+/* STRING:STRING (./rb-marshal.list:11) */
 extern void rb_marshal_STRING__STRING (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -511,7 +558,7 @@ rb_marshal_STRING__STRING (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* VOID:BOOLEAN,BOOLEAN (./rb-marshal.list:11) */
+/* VOID:BOOLEAN,BOOLEAN (./rb-marshal.list:12) */
 extern void rb_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -554,7 +601,7 @@ rb_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* BOXED:BOXED (./rb-marshal.list:12) */
+/* BOXED:BOXED (./rb-marshal.list:13) */
 extern void rb_marshal_BOXED__BOXED (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -599,7 +646,7 @@ rb_marshal_BOXED__BOXED (GClosure     *closure,
   g_value_take_boxed (return_value, v_return);
 }
 
-/* BOXED:OBJECT (./rb-marshal.list:13) */
+/* BOXED:OBJECT (./rb-marshal.list:14) */
 extern void rb_marshal_BOXED__OBJECT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
@@ -644,7 +691,7 @@ rb_marshal_BOXED__OBJECT (GClosure     *closure,
   g_value_take_boxed (return_value, v_return);
 }
 
-/* VOID:BOXED,BOXED (./rb-marshal.list:14) */
+/* VOID:BOXED,BOXED (./rb-marshal.list:15) */
 extern void rb_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -687,7 +734,7 @@ rb_marshal_VOID__BOXED_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,INT,POINTER,POINTER (./rb-marshal.list:15) */
+/* VOID:BOXED,INT,POINTER,POINTER (./rb-marshal.list:16) */
 extern void rb_marshal_VOID__BOXED_INT_POINTER_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -734,7 +781,7 @@ rb_marshal_VOID__BOXED_INT_POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,OBJECT (./rb-marshal.list:16) */
+/* VOID:BOXED,OBJECT (./rb-marshal.list:17) */
 extern void rb_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -777,7 +824,7 @@ rb_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,POINTER (./rb-marshal.list:17) */
+/* VOID:BOXED,POINTER (./rb-marshal.list:18) */
 extern void rb_marshal_VOID__BOXED_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -820,7 +867,7 @@ rb_marshal_VOID__BOXED_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,STRING,BOXED (./rb-marshal.list:18) */
+/* VOID:BOXED,STRING,BOXED (./rb-marshal.list:19) */
 extern void rb_marshal_VOID__BOXED_STRING_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -865,7 +912,7 @@ rb_marshal_VOID__BOXED_STRING_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,ULONG (./rb-marshal.list:19) */
+/* VOID:BOXED,ULONG (./rb-marshal.list:20) */
 extern void rb_marshal_VOID__BOXED_ULONG (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -908,7 +955,7 @@ rb_marshal_VOID__BOXED_ULONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:DOUBLE,LONG (./rb-marshal.list:20) */
+/* VOID:DOUBLE,LONG (./rb-marshal.list:21) */
 extern void rb_marshal_VOID__DOUBLE_LONG (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -951,7 +998,7 @@ rb_marshal_VOID__DOUBLE_LONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT64 (./rb-marshal.list:21) */
+/* VOID:UINT64 (./rb-marshal.list:22) */
 extern void rb_marshal_VOID__UINT64 (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -992,7 +1039,7 @@ rb_marshal_VOID__UINT64 (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT (./rb-marshal.list:22) */
+/* VOID:INT,INT (./rb-marshal.list:23) */
 extern void rb_marshal_VOID__INT_INT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
@@ -1035,7 +1082,7 @@ rb_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT,DOUBLE (./rb-marshal.list:23) */
+/* VOID:INT,INT,DOUBLE (./rb-marshal.list:24) */
 extern void rb_marshal_VOID__INT_INT_DOUBLE (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -1080,7 +1127,7 @@ rb_marshal_VOID__INT_INT_DOUBLE (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT,INT (./rb-marshal.list:24) */
+/* VOID:OBJECT,INT,INT (./rb-marshal.list:25) */
 extern void rb_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -1125,7 +1172,7 @@ rb_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./rb-marshal.list:25) */
+/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./rb-marshal.list:26) */
 extern void rb_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -1176,7 +1223,7 @@ rb_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT,POINTER (./rb-marshal.list:26) */
+/* VOID:OBJECT,INT,POINTER (./rb-marshal.list:27) */
 extern void rb_marshal_VOID__OBJECT_INT_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -1221,7 +1268,7 @@ rb_marshal_VOID__OBJECT_INT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,INT (./rb-marshal.list:27) */
+/* VOID:POINTER,INT (./rb-marshal.list:28) */
 extern void rb_marshal_VOID__POINTER_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -1264,7 +1311,7 @@ rb_marshal_VOID__POINTER_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,INT,POINTER (./rb-marshal.list:28) */
+/* VOID:POINTER,INT,POINTER (./rb-marshal.list:29) */
 extern void rb_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -1309,7 +1356,7 @@ rb_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,LONG,LONG (./rb-marshal.list:29) */
+/* VOID:POINTER,LONG,LONG (./rb-marshal.list:30) */
 extern void rb_marshal_VOID__POINTER_LONG_LONG (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -1354,7 +1401,50 @@ rb_marshal_VOID__POINTER_LONG_LONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (./rb-marshal.list:30) */
+/* VOID:POINTER,OBJECT (./rb-marshal.list:31) */
+extern void rb_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
+                                             GValue       *return_value,
+                                             guint         n_param_values,
+                                             const GValue *param_values,
+                                             gpointer      invocation_hint,
+                                             gpointer      marshal_data);
+void
+rb_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
+                                 GValue       *return_value G_GNUC_UNUSED,
+                                 guint         n_param_values,
+                                 const GValue *param_values,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
+                                 gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__POINTER_OBJECT) (gpointer     data1,
+                                                     gpointer     arg_1,
+                                                     gpointer     arg_2,
+                                                     gpointer     data2);
+  register GMarshalFunc_VOID__POINTER_OBJECT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__POINTER_OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_pointer (param_values + 1),
+            g_marshal_value_peek_object (param_values + 2),
+            data2);
+}
+
+/* VOID:POINTER,POINTER (./rb-marshal.list:32) */
 extern void rb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -1397,7 +1487,7 @@ rb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER,POINTER (./rb-marshal.list:31) */
+/* VOID:POINTER,POINTER,POINTER (./rb-marshal.list:33) */
 extern void rb_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -1442,7 +1532,7 @@ rb_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,UINT (./rb-marshal.list:32) */
+/* VOID:POINTER,UINT (./rb-marshal.list:34) */
 extern void rb_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -1485,7 +1575,7 @@ rb_marshal_VOID__POINTER_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,ULONG (./rb-marshal.list:33) */
+/* VOID:POINTER,ULONG (./rb-marshal.list:35) */
 extern void rb_marshal_VOID__POINTER_ULONG (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -1528,7 +1618,7 @@ rb_marshal_VOID__POINTER_ULONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,DOUBLE (./rb-marshal.list:34) */
+/* VOID:STRING,DOUBLE (./rb-marshal.list:36) */
 extern void rb_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -1571,7 +1661,7 @@ rb_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (./rb-marshal.list:35) */
+/* VOID:STRING,INT (./rb-marshal.list:37) */
 extern void rb_marshal_VOID__STRING_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -1614,7 +1704,7 @@ rb_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,POINTER (./rb-marshal.list:36) */
+/* VOID:STRING,POINTER (./rb-marshal.list:38) */
 extern void rb_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -1657,7 +1747,7 @@ rb_marshal_VOID__STRING_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING (./rb-marshal.list:37) */
+/* VOID:STRING,STRING (./rb-marshal.list:39) */
 extern void rb_marshal_VOID__STRING_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -1700,7 +1790,7 @@ rb_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,OBJECT (./rb-marshal.list:38) */
+/* VOID:STRING,STRING,OBJECT (./rb-marshal.list:40) */
 extern void rb_marshal_VOID__STRING_STRING_OBJECT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -1745,7 +1835,7 @@ rb_marshal_VOID__STRING_STRING_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,STRING (./rb-marshal.list:39) */
+/* VOID:STRING,STRING,STRING (./rb-marshal.list:41) */
 extern void rb_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -1790,7 +1880,7 @@ rb_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,STRING,UINT,BOOLEAN (./rb-marshal.list:40) */
+/* VOID:STRING,STRING,STRING,UINT,BOOLEAN (./rb-marshal.list:42) */
 extern void rb_marshal_VOID__STRING_STRING_STRING_UINT_BOOLEAN (GClosure     *closure,
                                                                 GValue       *return_value,
                                                                 guint         n_param_values,
@@ -1839,7 +1929,56 @@ rb_marshal_VOID__STRING_STRING_STRING_UINT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:ULONG,FLOAT (./rb-marshal.list:41) */
+/* VOID:UINT,STRING,STRING,OBJECT,BOOLEAN (./rb-marshal.list:43) */
+extern void rb_marshal_VOID__UINT_STRING_STRING_OBJECT_BOOLEAN (GClosure     *closure,
+                                                                GValue       *return_value,
+                                                                guint         n_param_values,
+                                                                const GValue *param_values,
+                                                                gpointer      invocation_hint,
+                                                                gpointer      marshal_data);
+void
+rb_marshal_VOID__UINT_STRING_STRING_OBJECT_BOOLEAN (GClosure     *closure,
+                                                    GValue       *return_value G_GNUC_UNUSED,
+                                                    guint         n_param_values,
+                                                    const GValue *param_values,
+                                                    gpointer      invocation_hint G_GNUC_UNUSED,
+                                                    gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__UINT_STRING_STRING_OBJECT_BOOLEAN) (gpointer     data1,
+                                                                        guint        arg_1,
+                                                                        gpointer     arg_2,
+                                                                        gpointer     arg_3,
+                                                                        gpointer     arg_4,
+                                                                        gboolean     arg_5,
+                                                                        gpointer     data2);
+  register GMarshalFunc_VOID__UINT_STRING_STRING_OBJECT_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 6);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__UINT_STRING_STRING_OBJECT_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_uint (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            g_marshal_value_peek_string (param_values + 3),
+            g_marshal_value_peek_object (param_values + 4),
+            g_marshal_value_peek_boolean (param_values + 5),
+            data2);
+}
+
+/* VOID:ULONG,FLOAT (./rb-marshal.list:44) */
 extern void rb_marshal_VOID__ULONG_FLOAT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -1882,7 +2021,7 @@ rb_marshal_VOID__ULONG_FLOAT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOOLEAN (./rb-marshal.list:42) */
+/* VOID:OBJECT,BOOLEAN (./rb-marshal.list:45) */
 extern void rb_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -1925,7 +2064,7 @@ rb_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,POINTER,POINTER (./rb-marshal.list:43) */
+/* VOID:STRING,STRING,POINTER,POINTER (./rb-marshal.list:46) */
 extern void rb_marshal_VOID__STRING_STRING_POINTER_POINTER (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
