@@ -6,7 +6,15 @@
 
 G_BEGIN_DECLS
 
-/* BOOLEAN:BOOLEAN,BOOLEAN,BOOLEAN (./rb-marshal.list:1) */
+/* BOOLEAN:BOOLEAN,BOOLEAN (./rb-marshal.list:1) */
+extern void rb_marshal_BOOLEAN__BOOLEAN_BOOLEAN (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data);
+
+/* BOOLEAN:BOOLEAN,BOOLEAN,BOOLEAN (./rb-marshal.list:2) */
 extern void rb_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -14,7 +22,7 @@ extern void rb_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);
 
-/* BOOLEAN:BOXED (./rb-marshal.list:2) */
+/* BOOLEAN:BOXED (./rb-marshal.list:3) */
 extern void rb_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -22,7 +30,7 @@ extern void rb_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* BOOLEAN:POINTER (./rb-marshal.list:3) */
+/* BOOLEAN:POINTER (./rb-marshal.list:4) */
 extern void rb_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -30,7 +38,7 @@ extern void rb_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
 
-/* BOOLEAN:POINTER,POINTER,POINTER (./rb-marshal.list:4) */
+/* BOOLEAN:POINTER,POINTER,POINTER (./rb-marshal.list:5) */
 extern void rb_marshal_BOOLEAN__POINTER_POINTER_POINTER (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -38,7 +46,7 @@ extern void rb_marshal_BOOLEAN__POINTER_POINTER_POINTER (GClosure     *closure,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);
 
-/* BOOLEAN:STRING,BOOLEAN (./rb-marshal.list:5) */
+/* BOOLEAN:STRING,BOOLEAN (./rb-marshal.list:6) */
 extern void rb_marshal_BOOLEAN__STRING_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -46,7 +54,7 @@ extern void rb_marshal_BOOLEAN__STRING_BOOLEAN (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* BOOLEAN:STRING,STRING,OBJECT (./rb-marshal.list:6) */
+/* BOOLEAN:STRING,STRING,OBJECT (./rb-marshal.list:7) */
 extern void rb_marshal_BOOLEAN__STRING_STRING_OBJECT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -54,7 +62,7 @@ extern void rb_marshal_BOOLEAN__STRING_STRING_OBJECT (GClosure     *closure,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
 
-/* INT:VOID (./rb-marshal.list:7) */
+/* INT:VOID (./rb-marshal.list:8) */
 extern void rb_marshal_INT__VOID (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
@@ -62,7 +70,7 @@ extern void rb_marshal_INT__VOID (GClosure     *closure,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);
 
-/* OBJECT:OBJECT (./rb-marshal.list:8) */
+/* OBJECT:OBJECT (./rb-marshal.list:9) */
 extern void rb_marshal_OBJECT__OBJECT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -70,7 +78,7 @@ extern void rb_marshal_OBJECT__OBJECT (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* OBJECT:VOID (./rb-marshal.list:9) */
+/* OBJECT:VOID (./rb-marshal.list:10) */
 extern void rb_marshal_OBJECT__VOID (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -78,7 +86,7 @@ extern void rb_marshal_OBJECT__VOID (GClosure     *closure,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
 
-/* STRING:STRING (./rb-marshal.list:10) */
+/* STRING:STRING (./rb-marshal.list:11) */
 extern void rb_marshal_STRING__STRING (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -86,7 +94,7 @@ extern void rb_marshal_STRING__STRING (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* VOID:BOOLEAN,BOOLEAN (./rb-marshal.list:11) */
+/* VOID:BOOLEAN,BOOLEAN (./rb-marshal.list:12) */
 extern void rb_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -94,7 +102,7 @@ extern void rb_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* BOXED:BOXED (./rb-marshal.list:12) */
+/* BOXED:BOXED (./rb-marshal.list:13) */
 extern void rb_marshal_BOXED__BOXED (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -102,7 +110,7 @@ extern void rb_marshal_BOXED__BOXED (GClosure     *closure,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
 
-/* BOXED:OBJECT (./rb-marshal.list:13) */
+/* BOXED:OBJECT (./rb-marshal.list:14) */
 extern void rb_marshal_BOXED__OBJECT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
@@ -110,7 +118,7 @@ extern void rb_marshal_BOXED__OBJECT (GClosure     *closure,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
 
-/* VOID:BOXED,BOXED (./rb-marshal.list:14) */
+/* VOID:BOXED,BOXED (./rb-marshal.list:15) */
 extern void rb_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -118,7 +126,7 @@ extern void rb_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:BOXED,INT,POINTER,POINTER (./rb-marshal.list:15) */
+/* VOID:BOXED,INT,POINTER,POINTER (./rb-marshal.list:16) */
 extern void rb_marshal_VOID__BOXED_INT_POINTER_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -126,7 +134,7 @@ extern void rb_marshal_VOID__BOXED_INT_POINTER_POINTER (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* VOID:BOXED,OBJECT (./rb-marshal.list:16) */
+/* VOID:BOXED,OBJECT (./rb-marshal.list:17) */
 extern void rb_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -134,7 +142,7 @@ extern void rb_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:BOXED,POINTER (./rb-marshal.list:17) */
+/* VOID:BOXED,POINTER (./rb-marshal.list:18) */
 extern void rb_marshal_VOID__BOXED_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -142,7 +150,7 @@ extern void rb_marshal_VOID__BOXED_POINTER (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:BOXED,STRING,BOXED (./rb-marshal.list:18) */
+/* VOID:BOXED,STRING,BOXED (./rb-marshal.list:19) */
 extern void rb_marshal_VOID__BOXED_STRING_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -150,7 +158,7 @@ extern void rb_marshal_VOID__BOXED_STRING_BOXED (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:BOXED,ULONG (./rb-marshal.list:19) */
+/* VOID:BOXED,ULONG (./rb-marshal.list:20) */
 extern void rb_marshal_VOID__BOXED_ULONG (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -158,7 +166,7 @@ extern void rb_marshal_VOID__BOXED_ULONG (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:DOUBLE,LONG (./rb-marshal.list:20) */
+/* VOID:DOUBLE,LONG (./rb-marshal.list:21) */
 extern void rb_marshal_VOID__DOUBLE_LONG (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -166,7 +174,7 @@ extern void rb_marshal_VOID__DOUBLE_LONG (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:UINT64 (./rb-marshal.list:21) */
+/* VOID:UINT64 (./rb-marshal.list:22) */
 extern void rb_marshal_VOID__UINT64 (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -174,7 +182,7 @@ extern void rb_marshal_VOID__UINT64 (GClosure     *closure,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
 
-/* VOID:INT,INT (./rb-marshal.list:22) */
+/* VOID:INT,INT (./rb-marshal.list:23) */
 extern void rb_marshal_VOID__INT_INT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
@@ -182,7 +190,7 @@ extern void rb_marshal_VOID__INT_INT (GClosure     *closure,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
 
-/* VOID:INT,INT,DOUBLE (./rb-marshal.list:23) */
+/* VOID:INT,INT,DOUBLE (./rb-marshal.list:24) */
 extern void rb_marshal_VOID__INT_INT_DOUBLE (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -190,7 +198,7 @@ extern void rb_marshal_VOID__INT_INT_DOUBLE (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:OBJECT,INT,INT (./rb-marshal.list:24) */
+/* VOID:OBJECT,INT,INT (./rb-marshal.list:25) */
 extern void rb_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -198,7 +206,7 @@ extern void rb_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./rb-marshal.list:25) */
+/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./rb-marshal.list:26) */
 extern void rb_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -206,7 +214,7 @@ extern void rb_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* VOID:OBJECT,INT,POINTER (./rb-marshal.list:26) */
+/* VOID:OBJECT,INT,POINTER (./rb-marshal.list:27) */
 extern void rb_marshal_VOID__OBJECT_INT_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -214,7 +222,7 @@ extern void rb_marshal_VOID__OBJECT_INT_POINTER (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:POINTER,INT (./rb-marshal.list:27) */
+/* VOID:POINTER,INT (./rb-marshal.list:28) */
 extern void rb_marshal_VOID__POINTER_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -222,7 +230,7 @@ extern void rb_marshal_VOID__POINTER_INT (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:POINTER,INT,POINTER (./rb-marshal.list:28) */
+/* VOID:POINTER,INT,POINTER (./rb-marshal.list:29) */
 extern void rb_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -230,7 +238,7 @@ extern void rb_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:POINTER,LONG,LONG (./rb-marshal.list:29) */
+/* VOID:POINTER,LONG,LONG (./rb-marshal.list:30) */
 extern void rb_marshal_VOID__POINTER_LONG_LONG (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -238,7 +246,15 @@ extern void rb_marshal_VOID__POINTER_LONG_LONG (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER (./rb-marshal.list:30) */
+/* VOID:POINTER,OBJECT (./rb-marshal.list:31) */
+extern void rb_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
+                                             GValue       *return_value,
+                                             guint         n_param_values,
+                                             const GValue *param_values,
+                                             gpointer      invocation_hint,
+                                             gpointer      marshal_data);
+
+/* VOID:POINTER,POINTER (./rb-marshal.list:32) */
 extern void rb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -246,7 +262,7 @@ extern void rb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER,POINTER (./rb-marshal.list:31) */
+/* VOID:POINTER,POINTER,POINTER (./rb-marshal.list:33) */
 extern void rb_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -254,7 +270,7 @@ extern void rb_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
 
-/* VOID:POINTER,UINT (./rb-marshal.list:32) */
+/* VOID:POINTER,UINT (./rb-marshal.list:34) */
 extern void rb_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -262,7 +278,7 @@ extern void rb_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:POINTER,ULONG (./rb-marshal.list:33) */
+/* VOID:POINTER,ULONG (./rb-marshal.list:35) */
 extern void rb_marshal_VOID__POINTER_ULONG (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -270,7 +286,7 @@ extern void rb_marshal_VOID__POINTER_ULONG (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:STRING,DOUBLE (./rb-marshal.list:34) */
+/* VOID:STRING,DOUBLE (./rb-marshal.list:36) */
 extern void rb_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -278,7 +294,7 @@ extern void rb_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:STRING,INT (./rb-marshal.list:35) */
+/* VOID:STRING,INT (./rb-marshal.list:37) */
 extern void rb_marshal_VOID__STRING_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -286,7 +302,7 @@ extern void rb_marshal_VOID__STRING_INT (GClosure     *closure,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
 
-/* VOID:STRING,POINTER (./rb-marshal.list:36) */
+/* VOID:STRING,POINTER (./rb-marshal.list:38) */
 extern void rb_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -294,7 +310,7 @@ extern void rb_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:STRING,STRING (./rb-marshal.list:37) */
+/* VOID:STRING,STRING (./rb-marshal.list:39) */
 extern void rb_marshal_VOID__STRING_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -302,7 +318,7 @@ extern void rb_marshal_VOID__STRING_STRING (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:STRING,STRING,OBJECT (./rb-marshal.list:38) */
+/* VOID:STRING,STRING,OBJECT (./rb-marshal.list:40) */
 extern void rb_marshal_VOID__STRING_STRING_OBJECT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -310,7 +326,7 @@ extern void rb_marshal_VOID__STRING_STRING_OBJECT (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* VOID:STRING,STRING,STRING (./rb-marshal.list:39) */
+/* VOID:STRING,STRING,STRING (./rb-marshal.list:41) */
 extern void rb_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -318,7 +334,7 @@ extern void rb_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* VOID:STRING,STRING,STRING,UINT,BOOLEAN (./rb-marshal.list:40) */
+/* VOID:STRING,STRING,STRING,UINT,BOOLEAN (./rb-marshal.list:42) */
 extern void rb_marshal_VOID__STRING_STRING_STRING_UINT_BOOLEAN (GClosure     *closure,
                                                                 GValue       *return_value,
                                                                 guint         n_param_values,
@@ -326,7 +342,15 @@ extern void rb_marshal_VOID__STRING_STRING_STRING_UINT_BOOLEAN (GClosure     *cl
                                                                 gpointer      invocation_hint,
                                                                 gpointer      marshal_data);
 
-/* VOID:ULONG,FLOAT (./rb-marshal.list:41) */
+/* VOID:UINT,STRING,STRING,OBJECT,BOOLEAN (./rb-marshal.list:43) */
+extern void rb_marshal_VOID__UINT_STRING_STRING_OBJECT_BOOLEAN (GClosure     *closure,
+                                                                GValue       *return_value,
+                                                                guint         n_param_values,
+                                                                const GValue *param_values,
+                                                                gpointer      invocation_hint,
+                                                                gpointer      marshal_data);
+
+/* VOID:ULONG,FLOAT (./rb-marshal.list:44) */
 extern void rb_marshal_VOID__ULONG_FLOAT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -334,7 +358,7 @@ extern void rb_marshal_VOID__ULONG_FLOAT (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:OBJECT,BOOLEAN (./rb-marshal.list:42) */
+/* VOID:OBJECT,BOOLEAN (./rb-marshal.list:45) */
 extern void rb_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -342,7 +366,7 @@ extern void rb_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:STRING,STRING,POINTER,POINTER (./rb-marshal.list:43) */
+/* VOID:STRING,STRING,POINTER,POINTER (./rb-marshal.list:46) */
 extern void rb_marshal_VOID__STRING_STRING_POINTER_POINTER (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
