@@ -7,6 +7,14 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
+ *  GStreamer plugins to be used and distributed together with GStreamer
+ *  and Rhythmbox. This permission is above and beyond the permissions granted
+ *  by the GPL license by which Rhythmbox is covered. If you modify this code
+ *  you may extend this exception to your version of the code, but you are not
+ *  obligated to do so. If you do not wish to do so, delete this exception
+ *  statement from your version.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -29,6 +37,16 @@
 #include "rb-debug.h"
 #include "rb-dialog.h"
 
+/**
+ * SECTION:rb-proxy-config
+ * @short_description: GConf HTTP proxy retriever
+ *
+ * This class knows how to retrieve the current HTTP proxy configuration
+ * from GConf, and also emits signals when the configuration is changed.
+ * It only supports manual proxy configuration (with authentication).  It
+ * does not support any of the various automatic proxy configuration schemes.
+ */
+
 enum
 {
 	CONFIG_CHANGED,
@@ -69,6 +87,12 @@ rb_proxy_config_class_init (RBProxyConfigClass *klass)
 	object_class->dispose = rb_proxy_config_dispose;
 	object_class->finalize = rb_proxy_config_finalize;
 
+	/**
+	 * RBProxyConfig::config-changed:
+	 * @config: the #RBProxyConfig
+	 *
+	 * Emitted when the HTTP proxy configuration is changed.
+	 */
 	rb_proxy_config_signals [CONFIG_CHANGED] =
 		g_signal_new ("config-changed",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -159,6 +183,11 @@ rb_proxy_config_finalize (GObject *object)
 	G_OBJECT_CLASS (rb_proxy_config_parent_class)->finalize (object);
 }
 
+/**
+ * rb_proxy_config_new:
+ *
+ * Return value: new proxy configuration retriever
+ */
 RBProxyConfig *
 rb_proxy_config_new ()
 {
@@ -231,26 +260,30 @@ get_proxy_config (RBProxyConfig *config)
 	}
 }
 
-#if defined(HAVE_LIBSOUP)
-SoupUri *
+/**
+ * rb_proxy_config_get_libsoup_uri:
+ * @config: a #RBProxyConfig
+ *
+ * Return value: a libsoup URI object containing the current HTTP proxy configuration.
+ */
+SoupURI *
 rb_proxy_config_get_libsoup_uri (RBProxyConfig *config)
 {
-	SoupUri *uri = NULL;
+	SoupURI *uri = NULL;
 
 	if (!config->enabled)
 		return NULL;
 
-	uri = g_new0 (SoupUri, 1);
-	uri->protocol = SOUP_PROTOCOL_HTTP;
+	uri = soup_uri_new (NULL);
+	soup_uri_set_scheme (uri, SOUP_URI_SCHEME_HTTP);
+	soup_uri_set_host (uri, config->host);
+	soup_uri_set_port (uri, config->port);
 
-	uri->host = g_strdup (config->host);
-	uri->port = config->port;
 	if (config->auth_enabled) {
-		uri->user = g_strdup (config->username);
-		uri->passwd = g_strdup (config->password);
+		soup_uri_set_user (uri, config->username);
+		soup_uri_set_password (uri, config->password);
 	}
 
 	return uri;
 }
-#endif
 
