@@ -9,6 +9,14 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
+ *  GStreamer plugins to be used and distributed together with GStreamer
+ *  and Rhythmbox. This permission is above and beyond the permissions granted
+ *  by the GPL license by which Rhythmbox is covered. If you modify this code
+ *  you may extend this exception to your version of the code, but you are not
+ *  obligated to do so. If you do not wish to do so, delete this exception
+ *  statement from your version.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -34,8 +42,7 @@
 #include <unistd.h>
 #include <ctype.h>
 
-#include <libsoup/soup-headers.h>
-#include <libsoup/soup-misc.h>
+#include <libsoup/soup.h>
 
 #include <glib/gi18n.h>
 #include <gst/gst.h>
@@ -47,6 +54,12 @@
 #include "rb-debug.h"
 #include "rb-daap-plugin.h"
 
+/* needed for portability to some systems, e.g. Solaris */
+#ifndef MSG_NOSIGNAL
+#define MSG_NOSIGNAL 0
+#endif
+
+
 #define RB_TYPE_DAAP_SRC (rb_daap_src_get_type())
 #define RB_DAAP_SRC(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj),RB_TYPE_DAAP_SRC,RBDAAPSrc))
 #define RB_DAAP_SRC_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass),RB_TYPE_DAAP_SRC,RBDAAPSrcClass))
@@ -426,7 +439,7 @@ rb_daap_src_open (RBDAAPSrc *src)
 	gchar *host;
 	guint port;
 	gchar *path;
-	GHashTable *header_table;
+	SoupMessageHeaders *header_table;
 	gchar *request;
 	gchar *response;
 	gchar *end_headers;
@@ -435,7 +448,6 @@ rb_daap_src_open (RBDAAPSrc *src)
 	guint http_status;
 	gchar *http_status_phrase = NULL;
 	gboolean parse_result;
-	char *dup_headers;
 
 	if (src->buffer_base) {
 		g_free (src->buffer_base);
@@ -530,59 +542,36 @@ rb_daap_src_open (RBDAAPSrc *src)
 		return FALSE;
 	}
 
-	/* for compatibility with older versions of libsoup, we may need to retry
-	 * the soup_headers_parse_response call with slightly different arguments.
-	 * since this function modifies the string passed in, we need to copy it
-	 * before the first call.
-	 *
-	 * > 2.2.99 wants the full response header, including the trailing blank line,
-	 * with the length passed in up to the start of the start of the trailing
-	 * blank line.
-	 */
-	dup_headers = g_strndup (response, (end_headers + 4) - response);
-
-	header_table = g_hash_table_new (soup_str_case_hash, soup_str_case_equal);
-	parse_result = soup_headers_parse_response (dup_headers,
+	header_table = soup_message_headers_new (SOUP_MESSAGE_HEADERS_RESPONSE);
+	parse_result = soup_headers_parse_response (response,
 						    ((end_headers+2) - response),
 						    header_table,
 						    NULL,
 						    &http_status,
 						    &http_status_phrase);
-	g_free (dup_headers);
-	if (parse_result == FALSE) {
-		/*
-		 * < 2.2.98 wants the headers terminated before the trailing blank line.
-		 */
-		end_headers[2] = '\0';
-		parse_result = soup_headers_parse_response (response,
-							    (end_headers+2 - response),
-							    header_table,
-							    NULL,
-							    &http_status,
-							    &http_status_phrase);
-	}
 
 	if (parse_result) {
 		if (http_status == 200 || http_status == 206) {
-			GSList *val;
+			const char *enc_str = NULL;
+			const char *len_str = NULL;
+			enc_str = soup_message_headers_get (header_table, "Transfer-Encoding");
+			len_str = soup_message_headers_get (header_table, "Content-Length");
 
-			val = g_hash_table_lookup (header_table, "Transfer-Encoding");
-			if (val) {
-				if (g_strcasecmp ((gchar *)val->data, "chunked") == 0) {
+			if (enc_str) {
+				if (g_ascii_strcasecmp (enc_str, "chunked") == 0) {
 					src->chunked = TRUE;
 				} else {
 					GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ, (NULL),
-							   ("Unknown HTTP transfer encoding \"%s\"", val->data));
+							   ("Unknown HTTP transfer encoding \"%s\"", enc_str));
 				}
 			} else {
 				src->chunked = FALSE;
-				val = g_hash_table_lookup (header_table, "Content-Length");
-				if (val) {
+				if (len_str) {
 					char *e;
-					src->size = strtoul ((char *)val->data, &e, 10);
-					if (e == val->data) {
+					src->size = strtoul (len_str, &e, 10);
+					if (e == len_str) {
 						GST_ELEMENT_ERROR (src, RESOURCE, OPEN_READ, (NULL),
-								   ("Couldn't read HTTP content length \"%s\"", val->data));
+								   ("Couldn't read HTTP content length \"%s\"", len_str));
 						ok = FALSE;
 					}
 				} else {
@@ -603,8 +592,8 @@ rb_daap_src_open (RBDAAPSrc *src)
 		ok = FALSE;
 	}
 	g_free (http_status_phrase);
-	soup_message_clear_headers (header_table);
-	g_hash_table_destroy (header_table);
+
+	soup_message_headers_free (header_table);
 
 	end_headers += 4;
 
