@@ -8,7 +8,7 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  The Rhythmbox authors hereby grants permission for non-GPL compatible
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
  *  GStreamer plugins to be used and distributed together with GStreamer
  *  and Rhythmbox. This permission is above and beyond the permissions granted
  *  by the GPL license by which Rhythmbox is covered. If you modify this code
@@ -35,7 +35,6 @@
 #include "rhythmdb.h"
 
 #include <totem-pl-parser.h>
-#include <libgnomevfs/gnome-vfs-volume.h>
 
 G_BEGIN_DECLS
 
@@ -62,13 +61,11 @@ typedef struct
 	char *		(*impl_uri_from_playlist_uri) (RBGenericPlayerSource *source, const char *uri);
 	char *		(*impl_uri_to_playlist_uri) (RBGenericPlayerSource *source, const char *uri);
 
-#if ENABLE_TRACK_TRANSFER
 	/* used for track transfer - returns the filename relative to the audio folder on the device */
 	char *		(*impl_build_filename) (RBGenericPlayerSource *source, RhythmDBEntry *entry);
-#endif
 } RBGenericPlayerSourceClass;
 
-RBRemovableMediaSource *rb_generic_player_source_new			(RBShell *shell, GnomeVFSVolume *volume);
+RBRemovableMediaSource *rb_generic_player_source_new			(RBShell *shell, GMount *mount);
 GType			rb_generic_player_source_get_type		(void);
 GType			rb_generic_player_source_register_type		(GTypeModule *module);
 
@@ -82,7 +79,7 @@ void			rb_generic_player_source_set_supported_formats  (RBGenericPlayerSource *s
 TotemPlParserType	rb_generic_player_source_get_playlist_format	(RBGenericPlayerSource *source);
 char *			rb_generic_player_source_get_playlist_path	(RBGenericPlayerSource *source);
 
-gboolean		rb_generic_player_is_volume_player		(GnomeVFSVolume *volume);
+gboolean		rb_generic_player_is_mount_player		(GMount *mount);
 
 
 /* for subclasses */
