@@ -2,13 +2,21 @@
  *
  *  arch-tag: Implementation of Nokia 770 source object
  *
- *  Copyright (C) 2006 James Livingston  <jrl@ids.org.au>
+ *  Copyright (C) 2006 James Livingston  <doclivingston@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
+ *  GStreamer plugins to be used and distributed together with GStreamer
+ *  and Rhythmbox. This permission is above and beyond the permissions granted
+ *  by the GPL license by which Rhythmbox is covered. If you modify this code
+ *  you may extend this exception to your version of the code, but you are not
+ *  obligated to do so. If you do not wish to do so, delete this exception
+ *  statement from your version.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -30,8 +38,6 @@
 #include <gtk/gtk.h>
 #include <dbus/dbus.h>
 #include <libhal.h>
-#include <libgnomevfs/gnome-vfs-volume.h>
-#include <libgnomevfs/gnome-vfs-volume-monitor.h>
 
 #include "eel-gconf-extensions.h"
 #include "rb-nokia770-source.h"
@@ -42,7 +48,7 @@
 #include "rb-plugin.h"
 
 
-static char * impl_transform_playlist_uri (RBGenericPlayerSource *source, const char *uri);
+static char * impl_uri_from_playlist_uri (RBGenericPlayerSource *source, const char *uri);
 
 
 typedef struct {
@@ -62,7 +68,7 @@ rb_nokia770_source_class_init (RBNokia770SourceClass *klass)
 {
 	RBGenericPlayerSourceClass *generic_class = RB_GENERIC_PLAYER_SOURCE_CLASS (klass);
 
-	generic_class->impl_transform_playlist_uri = impl_transform_playlist_uri;
+	generic_class->impl_uri_from_playlist_uri = impl_uri_from_playlist_uri;
 
 	g_type_class_add_private (klass, sizeof (RBNokia770SourcePrivate));
 }
@@ -74,27 +80,33 @@ rb_nokia770_source_init (RBNokia770Source *source)
 }
 
 RBRemovableMediaSource *
-rb_nokia770_source_new (RBShell *shell, GnomeVFSVolume *volume)
+rb_nokia770_source_new (RBShell *shell, GMount *mount)
 {
 	RBNokia770Source *source;
 	RhythmDBEntryType entry_type;
 	RhythmDB *db;
+	GVolume *volume;
 	char *name;
 	char *path;
 
-	g_assert (rb_nokia770_is_volume_player (volume));
+	g_assert (rb_nokia770_is_mount_player (mount));
+
+	volume = g_mount_get_volume (mount);
 
 	g_object_get (G_OBJECT (shell), "db", &db, NULL);
-	path = gnome_vfs_volume_get_device_path (volume);
+	path = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
 	name = g_strdup_printf ("nokia770: %s", path);
 	entry_type = rhythmdb_entry_register_type (db, name);
-	g_object_unref (G_OBJECT (db));
+	g_object_unref (db);
 	g_free (name);
 	g_free (path);
+	g_object_unref (volume);
 
 	source = RB_NOKIA770_SOURCE (g_object_new (RB_TYPE_NOKIA770_SOURCE,
 						   "entry-type", entry_type,
-						   "volume", volume,
+						   "ignore-entry-type", RHYTHMDB_ENTRY_TYPE_INVALID,
+						   "error-entry-type", RHYTHMDB_ENTRY_TYPE_INVALID,
+						   "mount", mount,
 						   "shell", shell,
 						   "source-group", RB_SOURCE_GROUP_DEVICES,
 						   NULL));
@@ -105,7 +117,7 @@ rb_nokia770_source_new (RBShell *shell, GnomeVFSVolume *volume)
 }
 
 static char *
-impl_transform_playlist_uri (RBGenericPlayerSource *source, const char *uri)
+impl_uri_from_playlist_uri (RBGenericPlayerSource *source, const char *uri)
 {
 	const char *path;
 	char *local_uri;
@@ -124,14 +136,12 @@ impl_transform_playlist_uri (RBGenericPlayerSource *source, const char *uri)
 }
 
 
-#ifdef HAVE_HAL
-
 static gboolean
-hal_udi_is_nokia770 (const char *udi)
+volume_is_nokia770 (GVolume *volume)
 {
 	LibHalContext *ctx;
 	DBusConnection *conn;
-	char *parent_udi;
+	char *parent_udi, *udi;
 	char *parent_name;
 	gboolean result;
 	DBusError error;
@@ -141,6 +151,7 @@ hal_udi_is_nokia770 (const char *udi)
 	dbus_error_init (&error);
 
 	conn = NULL;
+	udi = NULL;
 	parent_udi = NULL;
 	parent_name = NULL;
 
@@ -157,6 +168,10 @@ hal_udi_is_nokia770 (const char *udi)
 	if (!libhal_ctx_init (ctx, &error) || dbus_error_is_set (&error))
 		goto end;
 
+	udi = rb_gvolume_get_udi (volume, ctx);
+	if (udi == NULL)
+		goto end;
+
 	inited = TRUE;
 	parent_udi = libhal_device_get_property_string (ctx,
 							udi,
@@ -194,6 +209,7 @@ hal_udi_is_nokia770 (const char *udi)
 	}
 
 end:
+	g_free (udi);
 	g_free (parent_name);
 	g_free (parent_udi);
 
@@ -213,26 +229,19 @@ end:
 
 	return result;
 }
-#endif
 
 gboolean
-rb_nokia770_is_volume_player (GnomeVFSVolume *volume)
+rb_nokia770_is_mount_player (GMount *mount)
 {
-	gboolean result = FALSE;
-	gchar *str;
+	gboolean result;
+	GVolume *volume;
 
-	if (gnome_vfs_volume_get_volume_type (volume) != GNOME_VFS_VOLUME_TYPE_MOUNTPOINT) {
+	volume = g_mount_get_volume (mount);
+	if (volume == NULL)
 		return FALSE;
-	}
 
-	str = gnome_vfs_volume_get_hal_udi (volume);
-	if (str != NULL) {
-		gboolean result;
-
-		result = hal_udi_is_nokia770 (str);
-		g_free (str);
-		return result;
-	}
+	result = volume_is_nokia770 (volume);
+	g_object_unref (volume);
 
 	return result;
 }
