@@ -7,6 +7,14 @@
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
  *
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
+ *  GStreamer plugins to be used and distributed together with GStreamer
+ *  and Rhythmbox. This permission is above and beyond the permissions granted
+ *  by the GPL license by which Rhythmbox is covered. If you modify this code
+ *  you may extend this exception to your version of the code, but you are not
+ *  obligated to do so. If you do not wish to do so, delete this exception
+ *  statement from your version.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -26,7 +34,7 @@
 #include <glib/gi18n.h>
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gio/gio.h>
 
 #include "rb-debug.h"
 #include "rb-shell-binding.h"
@@ -93,9 +101,7 @@ static GOptionEntry args[] = {
 	{ "print-playing", 0, 0, G_OPTION_ARG_NONE, &print_playing, N_("Print the title and artist of the playing song"), NULL },
 	{ "print-playing-format", 0, 0, G_OPTION_ARG_STRING, &print_playing_format, N_("Print formatted details of the song"), NULL },
 
-#if GLIB_CHECK_VERSION(2,12,0)
 	{ "set-volume", 0, 0, G_OPTION_ARG_DOUBLE, &set_volume, N_("Set the playback volume"), NULL },
-#endif
 	{ "volume-up", 0, 0, G_OPTION_ARG_NONE, &volume_up, N_("Increase the playback volume"), NULL },
 	{ "volume-down", 0, 0, G_OPTION_ARG_NONE, &volume_down, N_("Decrease the playback volume"), NULL },
 	{ "print-volume", 0, 0, G_OPTION_ARG_NONE, &print_volume, N_("Print the current playback volume"), NULL },
@@ -140,7 +146,7 @@ rb_make_duration_string (guint duration)
 	return str;
 }
 
-/**
+/*
  * Parse a filename pattern and replace markers with values from a TrackDetails
  * structure.
  *
@@ -164,6 +170,8 @@ rb_make_duration_string (guint duration)
  * %tS -- track artist sortname (lowercase)
  * %td -- track duration
  * %te -- track elapsed time
+ * %tb -- track bitrate
+ * %st -- stream title
  */
 static char *
 parse_pattern (const char *pattern, GHashTable *properties, guint elapsed)
@@ -223,14 +231,16 @@ parse_pattern (const char *pattern, GHashTable *properties, guint elapsed)
 				if (value)
 					string = g_value_dup_string (value);
 				break;
-			/*case 's':
-				string = sanitize_path (album sort name);
+			case 's':
+				value = g_hash_table_lookup (properties, "mb-artistsortname");
+				if (value)
+					string = g_value_dup_string (value);
 				break;
 			case 'S':
-				char *t = g_utf8_strdown (album sort name)
-				string = sanitize_path (t);
-				g_free (t);
-				break;*/
+				value = g_hash_table_lookup (properties, "mb-artistsortname");
+				if (value)
+					string = g_utf8_strdown (g_value_get_string (value), -1);
+				break;
 			case 'y':
 				/* Release year */
 				value = g_hash_table_lookup (properties, "year");
@@ -290,14 +300,16 @@ parse_pattern (const char *pattern, GHashTable *properties, guint elapsed)
 				if (value)
 					string = g_value_dup_string (value);
 				break;
-			/*case 's':
-				string = sanitize_path (artist sort name);
+			case 's':
+				value = g_hash_table_lookup (properties, "mb-artistsortname");
+				if (value)
+					string = g_value_dup_string (value);
 				break;
 			case 'S':
-				char *t = g_utf8_strdown (artist sort name)
-				string = sanitize_path (t);
-				g_free (t);
-				break;*/
+				value = g_hash_table_lookup (properties, "mb-artistsortname");
+				if (value)
+					string = g_utf8_strdown (g_value_get_string (value), -1);
+				break;
 			case 'n':
 				/* Track number */
 				value = g_hash_table_lookup (properties, "track-number");
@@ -320,12 +332,36 @@ parse_pattern (const char *pattern, GHashTable *properties, guint elapsed)
 				/* Track elapsed time */
 				string = rb_make_duration_string (elapsed);
 				break;
+			case 'b':
+				/* Track bitrate */
+				value = g_hash_table_lookup (properties, "bitrate");
+				if (value)
+					string = g_strdup_printf ("%u", g_value_get_uint (value));
+				break;
+
 			default:
 				string = g_strdup_printf ("%%t%c", *p);
  			}
 
 			break;
 
+		case 's':
+			/*
+			 * Stream tag
+			 */
+			switch (*++p) {
+			case 't':
+				value = g_hash_table_lookup (properties, "rb:stream-song-title");
+				if (value)
+					string = g_value_dup_string (value);
+				break;
+			default:
+				string = g_strdup_printf ("%%s%c", *p);
+ 			}
+
+			break;
+
+
 		default:
 			string = g_strdup_printf ("%%%c", *p);
 		}
@@ -375,31 +411,50 @@ create_rb_shell_proxies (DBusGConnection *bus, DBusGProxy **shell_proxy, DBusGPr
 	return TRUE;
 }
 
+static GHashTable *
+get_playing_song_info (DBusGProxy *shell_proxy, DBusGProxy *player_proxy, GError **error)
+{
+	char *playing_uri;
+	GHashTable *properties;
+
+	org_gnome_Rhythmbox_Player_get_playing_uri (player_proxy, &playing_uri, error);
+	if (*error != NULL) {
+		return NULL;
+	}
+
+	if (!playing_uri || playing_uri[0] == '\0') {
+		return NULL;
+	}
+
+	rb_debug ("playing song is %s", playing_uri);
+	org_gnome_Rhythmbox_Shell_get_song_properties (shell_proxy, playing_uri, &properties, error);
+	if (*error != NULL) {
+		return NULL;
+	}
+
+	return properties;
+}
+
 static void
 print_playing_song (DBusGProxy *shell_proxy, DBusGProxy *player_proxy, const char *format)
 {
-	char *playing_uri;
-	GError *error = NULL;
+	gboolean errored;
 	GHashTable *properties;
-	char *string;
 	guint elapsed = 0;
+	GError *error = NULL;
+	char *string;
 
-	org_gnome_Rhythmbox_Player_get_playing_uri (player_proxy, &playing_uri, &error);
-	if (annoy (&error))
+	properties = get_playing_song_info (shell_proxy, player_proxy, &error);
+	if (annoy (&error)) {
 		return;
-
-	org_gnome_Rhythmbox_Player_get_elapsed (player_proxy, &elapsed, &error);
-	annoy (&error);
-
-	if (!playing_uri || playing_uri[0] == '\0') {
+	}
+	if (properties == NULL) {
 		g_print ("%s\n", _("Not playing"));
 		return;
 	}
-	rb_debug ("playing song is %s", playing_uri);
-
-	org_gnome_Rhythmbox_Shell_get_song_properties (shell_proxy, playing_uri, &properties, &error);
-	if (annoy (&error))
-		return;
+	
+	org_gnome_Rhythmbox_Player_get_elapsed (player_proxy, &elapsed, &error);
+	annoy (&error);
 
 	string = parse_pattern (format, properties, elapsed);
 	g_print ("%s\n", string);
@@ -407,6 +462,34 @@ print_playing_song (DBusGProxy *shell_proxy, DBusGProxy *player_proxy, const cha
 	g_free (string);
 }
 
+static void
+print_playing_song_default (DBusGProxy *shell_proxy, DBusGProxy *player_proxy)
+{
+	gboolean errored;
+	GHashTable *properties;
+	char *string;
+	GError *error = NULL;
+
+	properties = get_playing_song_info (shell_proxy, player_proxy, &error);
+	if (annoy (&error)) {
+		return;
+	}
+	if (properties == NULL) {
+		g_print ("%s\n", _("Not playing"));
+		return;
+	}
+
+	if (g_hash_table_lookup (properties, "rb:stream-song-title") != NULL) {
+		string = parse_pattern ("%st (%tt)", properties, 0);
+	} else {
+		string = parse_pattern ("%ta - %tt", properties, 0);
+	}
+
+	g_print ("%s\n", string);
+	g_hash_table_destroy (properties);
+	g_free (string);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -540,35 +623,45 @@ main (int argc, char **argv)
 	if (other_stuff) {
 		int i;
 		for (i = 0; other_stuff[i] != NULL; i++) {
-			char *uri = gnome_vfs_make_uri_from_shell_arg (other_stuff[i]);
-			if (uri == NULL) {
+			GFile *file;
+			char *fileuri;
+
+			file = g_file_new_for_commandline_arg (other_stuff[i]);
+			fileuri = g_file_get_uri (file);
+			if (fileuri == NULL) {
 				g_warning ("couldn't convert \"%s\" to a URI", other_stuff[i]);
 				continue;
 			}
 
 			if (enqueue) {
-				rb_debug ("enqueueing %s", uri);
-				org_gnome_Rhythmbox_Shell_add_to_queue (shell_proxy, uri, &error);
+				rb_debug ("enqueueing %s", fileuri);
+				org_gnome_Rhythmbox_Shell_add_to_queue (shell_proxy, fileuri, &error);
 			} else {
-				rb_debug ("importing %s", uri);
-				org_gnome_Rhythmbox_Shell_load_ur_i (shell_proxy, uri, FALSE, &error);
+				rb_debug ("importing %s", fileuri);
+				org_gnome_Rhythmbox_Shell_load_ur_i (shell_proxy, fileuri, FALSE, &error);
 			}
 			annoy (&error);
-			g_free (uri);
+			g_free (fileuri);
+			g_object_unref (file);
 		}
 	}
 
 	/* play uri */
 	if (play_uri) {
-		char *uri = gnome_vfs_make_uri_from_shell_arg (play_uri);
-		if (uri == NULL) {
+		GFile *file;
+		char *fileuri;
+
+		file = g_file_new_for_commandline_arg (play_uri);
+		fileuri = g_file_get_uri (file);
+		if (fileuri == NULL) {
 			g_warning ("couldn't convert \"%s\" to a URI", play_uri);
 		} else {
-			rb_debug ("loading and playing %s", uri);
-			org_gnome_Rhythmbox_Shell_load_ur_i (shell_proxy, uri, TRUE, &error);
+			rb_debug ("loading and playing %s", fileuri);
+			org_gnome_Rhythmbox_Shell_load_ur_i (shell_proxy, fileuri, TRUE, &error);
 			annoy (&error);
 		}
-		g_free (uri);
+		g_free (fileuri);
+		g_object_unref (file);
 	}
 
 	/* 5. play/pause/stop */
@@ -589,13 +682,10 @@ main (int argc, char **argv)
 	}
 
 	/* 6. get/set volume, mute/unmute */
-#if GLIB_CHECK_VERSION(2,12,0)
 	if (set_volume > -0.01) {
 		org_gnome_Rhythmbox_Player_set_volume (player_proxy, set_volume, &error);
 		annoy (&error);
-	} else
-#endif
-	if (volume_up || volume_down) {
+	} else if (volume_up || volume_down) {
 		org_gnome_Rhythmbox_Player_set_volume_relative (player_proxy, volume_up ? 0.1 : -0.1, &error);
 		annoy (&error);
 	} else if (unmute || mute) {
@@ -621,7 +711,7 @@ main (int argc, char **argv)
 	if (print_playing_format) {
 		print_playing_song (shell_proxy, player_proxy, print_playing_format);
 	} else if (print_playing) {
-		print_playing_song (shell_proxy, player_proxy, "%ta - %tt");
+		print_playing_song_default (shell_proxy, player_proxy);
 	}
 
 	/* 8. display notification about playing song */
