@@ -9,7 +9,7 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  The Rhythmbox authors hereby grants permission for non-GPL compatible
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
  *  GStreamer plugins to be used and distributed together with GStreamer
  *  and Rhythmbox. This permission is above and beyond the permissions granted
  *  by the GPL license by which Rhythmbox is covered. If you modify this code
@@ -188,6 +188,10 @@ gint 			rhythmdb_query_model_double_ceiling_sort_func (RhythmDBEntry *a,
 gint 			rhythmdb_query_model_ulong_sort_func	(RhythmDBEntry *a,
 								 RhythmDBEntry *b,
 								 gpointer data);
+								 
+gint			rhythmdb_query_model_bitrate_sort_func  (RhythmDBEntry *a,
+								 RhythmDBEntry *b,
+								 gpointer data);
 
 gint 			rhythmdb_query_model_date_sort_func	(RhythmDBEntry *a,
 								 RhythmDBEntry *b,
