@@ -8,7 +8,7 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  The Rhythmbox authors hereby grants permission for non-GPL compatible
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
  *  GStreamer plugins to be used and distributed together with GStreamer
  *  and Rhythmbox. This permission is above and beyond the permissions granted
  *  by the GPL license by which Rhythmbox is covered. If you modify this code
@@ -32,6 +32,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gio/gio.h>
 #include <stdarg.h>
 #include <libxml/tree.h>
 
@@ -211,6 +212,7 @@ typedef enum
 	RHYTHMDB_PROP_MUSICBRAINZ_ALBUMID,
 	RHYTHMDB_PROP_MUSICBRAINZ_ALBUMARTISTID,
 	RHYTHMDB_PROP_ARTIST_SORTNAME,
+	RHYTHMDB_PROP_ALBUM_SORTNAME,
 
 	RHYTHMDB_NUM_PROPERTIES
 } RhythmDBPropType;
@@ -298,7 +300,7 @@ struct _RhythmDBClass
 
 	/* virtual methods */
 
-	gboolean	(*impl_load)		(RhythmDB *db, gboolean *dead, GError **error);
+	gboolean	(*impl_load)		(RhythmDB *db, GCancellable *cancel, GError **error);
 	void		(*impl_save)		(RhythmDB *db);
 
 	void		(*impl_entry_new)	(RhythmDB *db, RhythmDBEntry *entry);
@@ -381,6 +383,8 @@ void		rhythmdb_entry_set	(RhythmDB *db, RhythmDBEntry *entry,
 
 char *		rhythmdb_entry_get_playback_uri	(RhythmDBEntry *entry);
 
+gboolean	rhythmdb_entry_is_lossless (RhythmDBEntry *entry);
+
 gpointer	rhythmdb_entry_get_type_data (RhythmDBEntry *entry, guint expected_size);
 #define		RHYTHMDB_ENTRY_GET_TYPE_DATA(e,t)	((t*)rhythmdb_entry_get_type_data((e),sizeof(t)))
 
