@@ -9,7 +9,7 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  The Rhythmbox authors hereby grants permission for non-GPL compatible
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
  *  GStreamer plugins to be used and distributed together with GStreamer
  *  and Rhythmbox. This permission is above and beyond the permissions granted
  *  by the GPL license by which Rhythmbox is covered. If you modify this code
@@ -31,10 +31,10 @@
 #ifndef __RB_SOURCE_H
 #define __RB_SOURCE_H
 
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkactiongroup.h>
+#include <gtk/gtk.h>
 
 #include "rb-source-group.h"
+#include "rb-source-search.h"
 #include "rb-entry-view.h"
 #include "rb-shell-preferences.h"
 
@@ -47,9 +47,18 @@ typedef enum {
 	RB_SOURCE_EOF_NEXT,
 } RBSourceEOFType;
 
+typedef enum {
+	RB_SOURCE_SEARCH_NONE,
+	RB_SOURCE_SEARCH_INCREMENTAL,
+	RB_SOURCE_SEARCH_EXPLICIT,
+} RBSourceSearchType;
+
 GType rb_source_eof_type_get_type (void);
 #define RB_TYPE_SOURCE_EOF_TYPE	(rb_source_eof_type_get_type())
 
+GType rb_source_search_type_get_type (void);
+#define RB_TYPE_SOURCE_SEARCH_TYPE (rb_source_search_type_get_type())
+
 #define RB_TYPE_SOURCE         (rb_source_get_type ())
 #define RB_SOURCE(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), RB_TYPE_SOURCE, RBSource))
 #define RB_SOURCE_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), RB_TYPE_SOURCE, RBSourceClass))
@@ -93,9 +102,7 @@ struct _RBSourceClass
 
 	gboolean	(*impl_can_rename)	(RBSource *source);
 
-	gboolean	(*impl_can_search)	(RBSource *source);
-
-	void		(*impl_search)		(RBSource *source, const char *text);
+	void		(*impl_search)		(RBSource *source, RBSourceSearch *search, const char *cur_text, const char *new_text);
 	void		(*impl_reset_filters)	(RBSource *source);
 	GtkWidget *	(*impl_get_config_widget)(RBSource *source, RBShellPreferences *prefs);
 
@@ -157,9 +164,10 @@ GList *		rb_source_get_property_views	(RBSource *source);
 
 gboolean	rb_source_can_rename		(RBSource *source);
 
-gboolean	rb_source_can_search		(RBSource *source);
 void		rb_source_search		(RBSource *source,
-						 const char *text);
+						 RBSourceSearch *search,
+						 const char *cur_text,
+						 const char *new_text);
 
 void		rb_source_reset_filters		(RBSource *source);
 
